'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /* eslint-env jest */


var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _Toast = require('./../Toast');

var _Toast2 = _interopRequireDefault(_Toast);

var _DefaultCloseButton = require('./../DefaultCloseButton');

var _DefaultCloseButton2 = _interopRequireDefault(_DefaultCloseButton);

var _ProgressBar = require('./../ProgressBar');

var _ProgressBar2 = _interopRequireDefault(_ProgressBar);

var _config = require('./../config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var REQUIRED_PROPS = {
  closeButton: _react2.default.createElement(_DefaultCloseButton2.default, null),
  autoClose: 5000,
  closeToast: function closeToast() {},
  position: _config2.default.POSITION.TOP_RIGHT
};

describe('Toast', function () {
  it('Should not render ProgressBar if autoClose prop is set to false', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(
      _Toast2.default,
      _extends({}, REQUIRED_PROPS, {
        autoClose: false
      }),
      'FooBar'
    ));

    expect(component.children().find(_ProgressBar2.default).length).toBe(0);
  });

  it('Should not render closeButton if closeButton prop is set to false', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(
      _Toast2.default,
      _extends({}, REQUIRED_PROPS, {
        closeButton: false
      }),
      'FooBar'
    ));

    expect(component.children().find(_DefaultCloseButton2.default).length).toBe(0);
  });

  it('Can call onOpen callback when component mount', function () {
    var onOpen = jest.fn();
    (0, _enzyme.mount)(_react2.default.createElement(
      _Toast2.default,
      _extends({}, REQUIRED_PROPS, {
        onOpen: onOpen
      }),
      'FooBar'
    ));

    expect(onOpen).toHaveBeenCalled();
  });

  it('Can call onClose callback when component will unmount', function () {
    var onClose = jest.fn();
    var component = (0, _enzyme.mount)(_react2.default.createElement(
      _Toast2.default,
      _extends({}, REQUIRED_PROPS, {
        onClose: onClose
      }),
      'FooBar'
    ));

    component.unmount();
    expect(onClose).toHaveBeenCalled();
  });

  it('Should pause toast delay on mouse enter', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(
      _Toast2.default,
      REQUIRED_PROPS,
      'FooBar'
    ));

    expect(component.state('isRunning')).toBeTruthy();
    component.simulate('mouseEnter');
    expect(component.state('isRunning')).toBeFalsy();
  });

  it('Should play toast delay on mouse leave', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(
      _Toast2.default,
      REQUIRED_PROPS,
      'FooBar'
    ));

    expect(component.state('isRunning')).toBeTruthy();
    component.simulate('mouseEnter');
    expect(component.state('isRunning')).toBeFalsy();
    component.simulate('mouseLeave');
    expect(component.state('isRunning')).toBeTruthy();
  });

  it('Should not call setState if autoClose prop is false', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(
      _Toast2.default,
      _extends({}, REQUIRED_PROPS, {
        autoClose: false
      }),
      'FooBar'
    ));

    expect(component.state('isRunning')).toBeTruthy();
    component.simulate('mouseEnter');
    expect(component.state('isRunning')).toBeTruthy();
  });
});