'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzyme = require('enzyme');

var _ToastContainer = require('./../ToastContainer');

var _ToastContainer2 = _interopRequireDefault(_ToastContainer);

var _Toast = require('./../Toast');

var _Toast2 = _interopRequireDefault(_Toast);

var _toastify = require('./../toastify');

var _toastify2 = _interopRequireDefault(_toastify);

var _config = require('./../config');

var _config2 = _interopRequireDefault(_config);

var _EventManager = require('./../util/EventManager');

var _EventManager2 = _interopRequireDefault(_EventManager);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function hasProp(obj, key) {
  return Object.prototype.hasOwnProperty.call(obj, key);
} /* eslint-env jest */


describe('ToastContainer', function () {
  it('Should merge className and style', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_ToastContainer2.default, { className: 'plop', style: { background: 'red' } }));
    var expectedClassName = 'plop';
    var expectedStyle = { background: 'red' };

    expect(component.props().className).toContain(expectedClassName);
    expect(component.props().style).toMatchObject(expectedStyle);
  });

  it('Should bind event when mounted and unbind them when unmounted', function () {
    var component = (0, _enzyme.mount)(_react2.default.createElement(_ToastContainer2.default, null));

    expect(_EventManager2.default.eventList.has(_config2.default.ACTION.SHOW)).toBeTruthy();
    expect(_EventManager2.default.eventList.has(_config2.default.ACTION.CLEAR)).toBeTruthy();

    component.unmount();
    expect(_EventManager2.default.eventList.has(_config2.default.ACTION.SHOW)).toBeFalsy();
    expect(_EventManager2.default.eventList.has(_config2.default.ACTION.CLEAR)).toBeFalsy();
  });

  it('Should set style pointer events to none when there is no toast to render', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_ToastContainer2.default, null));
    expect(component.prop('style').pointerEvents).toEqual('none');
  });

  it('Should always pass down to Toast the props: \n    -autoClose\n    -closeButton\n    -children\n    -position\n    -closeToast', function () {
    var component = (0, _enzyme.mount)(_react2.default.createElement(_ToastContainer2.default, null));
    // Create a toast
    (0, _toastify2.default)('coucou');
    var props = component.children().find(_Toast2.default).props();
    ['autoClose', 'closeButton', 'children', 'position', 'closeToast'].forEach(function (key) {
      return expect(hasProp(props, key)).toBeTruthy();
    });
  });
});