'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propValidator = require('./../util/propValidator');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-env jest */
var ValidReactElement = function ValidReactElement() {
  return _react2.default.createElement(
    'div',
    null,
    'Hello'
  );
};

describe('Custom PropTypes', function () {
  describe('falseOrNumber', function () {
    it('Can be false or int', function () {
      var props = { autoClose: false };
      expect((0, _propValidator.falseOrNumber)(props, 'autoClose', 'TestComponent')).toBe(null);
      props.autoClose = 1000;
      expect((0, _propValidator.falseOrNumber)(props, 'autoClose', 'TestComponent')).toBe(null);
    });

    it('Should return an Error if int is <= 0 or prop equal to true', function () {
      var props = { autoClose: true };
      expect((0, _propValidator.falseOrNumber)(props, 'autoClose', 'TestComponent')).toBeInstanceOf(Error);

      props.autoClose = -1;
      expect((0, _propValidator.falseOrNumber)(props, 'autoClose', 'TestComponent')).toBeInstanceOf(Error);

      props.autoClose = 0;
      expect((0, _propValidator.falseOrNumber)(props, 'autoClose', 'TestComponent')).toBeInstanceOf(Error);
    });
  });

  describe('falseOrElement', function () {
    it('Can be false or a valid react element', function () {
      var props = { closeButton: false };
      expect((0, _propValidator.falseOrElement)(props, 'closeButton', 'TestComponent')).toBe(null);
      props.closeButton = _react2.default.createElement(ValidReactElement, null);
      expect((0, _propValidator.falseOrElement)(props, 'closeButton', 'TestComponent')).toBe(null);
    });

    it('Should return an Error if prop equal true or not a valid react element', function () {
      var props = { closeButton: true };
      expect((0, _propValidator.falseOrElement)(props, 'closeButton', 'TestComponent')).toBeInstanceOf(Error);

      props.closeButton = 'coucou';
      expect((0, _propValidator.falseOrElement)(props, 'closeButton', 'TestComponent')).toBeInstanceOf(Error);
    });
  });
  describe('Can be set as Required', function () {
    it('Should return an Error if the prop is required but undefined', function () {
      var props = {};

      expect(_propValidator.falseOrNumber.isRequired(props, 'autoClose', 'TestComponent')).toBeInstanceOf(Error);
      expect(_propValidator.falseOrElement.isRequired(props, 'closeButton', 'TestComponent')).toBeInstanceOf(Error);
    });
  });
});